issue_template = """
Please remove all of this template but the relevant section below, and fill in
each item in that section.

## Feature Request

### Feature Description

Describe in detail the feature you would like to see implemented, especially
how it would work from a user perspective and what benefits it adds. Your description
should be detailed enough to be used to determine if code written for the feature
adequately solves the problem.

### Use Cases

Describe one or more use cases for why this feature will be useful.

### Testing Assistance

Indicate whether or not you will be able to assist in testing pre-release
code for the feature.

## Bug Report

When reporting a bug, please provide all of the following information,
as well as any additional details that may be useful in reproducing or fixing
the issue:

### Version

{0} version, as reported by ``{0} --version``

### Installation Method

How was {0} installed (provide as much detail as possible, ideally
the exact command used and whether it was installed in a virtualenv or not).

### Supporting Software Versions

The output of ``python --version`` and ``virtualenv --version`` in the environment
that {0} is running in, as well as your operating system type and version.

### Actual Output

```
Paste here the output of {0} (including the command used to run it),
run with the -vv (debug-level output) flag, that shows the issue.
```

### Expected Output

Describe the output that you expected (what's wrong). If possible, after your description,
copy the actual output above and modify it to what was expected.

### Testing Assistance

Indicate whether or not you will be able to assist in testing pre-release
code for the feature.
"""
